@@ -19,14 +19,14 @@ class Canvas : public QGraphicsView
 
 	public:
 		explicit Canvas(QWidget *parent = nullptr);
-		~Canvas();
+		~Canvas() override;
 
 		double turtleAngle() { return turtle->angle(); }
 		QImage getPicture();
 		void saveAsSvg(const QString&, const QString&);
 // 		void scene() { return _scene; }
 
-	public slots:
+	public Q_SLOTS:
 		void slotClear();
 		void slotGo(double x, double y) { turtle->setPos(x, y); };
 		void slotGoX(double x) { turtle->setPos(x, turtle->pos().y()); }
@@ -54,13 +54,13 @@ class Canvas : public QGraphicsView
 		void getY(double& value);
 
 	protected:
-		void resizeEvent(QResizeEvent* event) Q_DECL_OVERRIDE;
+		void resizeEvent(QResizeEvent* event) override;
 
 	private:
 		void initValues();
 		QColor rgbDoublesToColor(double r, double g, double b);
 		void drawLine(double x1, double y1, double x2, double y2);
-		void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
+		void wheelEvent(QWheelEvent *event) override;
 		void scaleView(double scaleFactor);
 
 		QGraphicsScene            *_scene;
